@@ -1,18 +1,12 @@
-import json
 import logging
-import os
+from typing import Optional
 
 import boto3
 
-from botocore.errorfactory import ClientError
-from botocore.exceptions import NoCredentialsError, ParamValidationError
-from json import JSONDecodeError
-from figcli.config import *
-from figcli.models.assumable_role import AssumableRole
 from figcli.models.defaults.defaults import CLIDefaults
-from figcli.svcs.auth.okta.okta import Okta
 from figcli.svcs.auth.provider.session_provider import SessionProvider
-from figcli.utils.utils import Utils, InvalidSessionError
+from figcli.ui.models.global_environment import GlobalEnvironment
+from figcli.utils.utils import Utils
 
 log = logging.getLogger(__name__)
 
@@ -27,9 +21,10 @@ class SessionManager:
         self.session_provider: SessionProvider = session_provider
 
     @Utils.trace
-    def get_session(self, assumable_role: AssumableRole, prompt: bool, exit_on_fail=True) -> boto3.Session:
+    def get_session(self, env: GlobalEnvironment, prompt: bool, exit_on_fail=True,
+                    mfa: Optional[str] = None) -> boto3.Session:
         """
-        Creates a session in the specified ENV for the target role from a SAML assertion returned by OKTA authentication.
+        Creates a session in the specified ENV for the target role from a SAML assertion returned by SSO authentication.
         Args:
             assumable_role: AssumableRole - The role to be leveraged to authenticate this session
             prompt: If prompt is set, we will not use a cached session and will generate new sessions for okta and mgmt.
@@ -37,4 +32,4 @@ class SessionManager:
 
         returns: Hydrated session for role + account that match the specified one in the provided AssumableRole
         """
-        return self.session_provider.get_session(assumable_role, prompt, exit_on_fail=exit_on_fail)
\ No newline at end of file
+        return self.session_provider.get_session(env, prompt, exit_on_fail=exit_on_fail, mfa=mfa)
