@@ -8,10 +8,10 @@ from figcli.utils.utils import *
 
 class DataPut(FiggyTest):
     def __init__(self, extra_args=""):
-        super().__init__(pexpect.spawn(f'{CLI_NAME} config {Utils.get_first(put)} --env {DEFAULT_ENV} '
+        super().__init__(pexpect.spawn(f'{CLI_NAME} config {put.name} --env {DEFAULT_ENV} '
                                        f'--skip-upgrade {extra_args}',
                       timeout=20, encoding='utf-8'), extra_args=extra_args)
-        self.step(f"Testing `{CLI_NAME} config {Utils.get_first(put)} --env {DEFAULT_ENV}`")
+        self.step(f"Testing `{CLI_NAME} config {put.name} --env {DEFAULT_ENV}`")
 
     def run(self):
         self.expect('.*Please input a PS Name.*')
