@@ -9,7 +9,7 @@ from figcli.utils.utils import *
 class DevExport(FiggyTest):
 
     def __init__(self, extra_args=""):
-        super().__init__(pexpect.spawn(f'{CLI_NAME} {Utils.get_first(iam)} {Utils.get_first(export)} '
+        super().__init__(pexpect.spawn(f'{CLI_NAME} {iam.name} {export.name} '
                                     f'--env {DEFAULT_ENV} --skip-upgrade {extra_args}', timeout=5, encoding='utf-8'),
                                     extra_args=extra_args)
         self._child.delaybeforesend = .5
